@@ -439,7 +439,7 @@ class LayerGroup(Layer):
     _view_name = Unicode('LeafletLayerGroupView').tag(sync=True)
     _model_name = Unicode('LeafletLayerGroupModel').tag(sync=True)
 
-    layers = Tuple(trait=Instance(Layer)).tag(sync=True, **widget_serialization)
+    layers = Tuple().tag(trait=Instance(Layer), sync=True, **widget_serialization)
 
     _layer_ids = List()
 
@@ -467,6 +467,13 @@ class LayerGroup(Layer):
             raise LayerException('layer not on in layergroup: %r' % layer)
         self.layers = tuple([l for l in self.layers if l.model_id != layer.model_id])
 
+    def substitute_layer(self, old, new):
+        if isinstance(new, dict):
+            new = basemap_to_tiles(new)
+        if old.model_id not in self._layer_ids:
+            raise LayerException('Could not substitute layer: layer not in layergroup.')
+        self.layers = tuple([new if l.model_id == old.model_id else l for l in self.layers])
+
     def clear_layers(self):
         self.layers = ()
 
@@ -881,7 +888,7 @@ class Map(DOMWidget, InteractMixin):
     east = Float(def_loc[1], read_only=True).tag(sync=True)
     west = Float(def_loc[1], read_only=True).tag(sync=True)
 
-    layers = Tuple(trait=Instance(Layer)).tag(sync=True, **widget_serialization)
+    layers = Tuple().tag(trait=Instance(Layer), sync=True, **widget_serialization)
 
     @default('layers')
     def _default_layers(self):
@@ -968,7 +975,7 @@ class Map(DOMWidget, InteractMixin):
     def clear_layers(self):
         self.layers = ()
 
-    controls = Tuple(trait=Instance(Control)).tag(sync=True, **widget_serialization)
+    controls = Tuple().tag(trait=Instance(Control), sync=True, **widget_serialization)
     _control_ids = List()
 
     @validate('controls')
